pub struct AdClient {
pub arc_opt_in: Option<bool>,
pub id: Option<String>,
pub kind: Option<String>,
pub product_code: Option<String>,
pub supports_reporting: Option<bool>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
arc_opt_in: Option<bool>Whether this ad client is opted in to ARC.
id: Option<String>Unique identifier of this ad client.
kind: Option<String>Kind of resource this is, in this case adexchangeseller#adClient.
product_code: Option<String>This ad client’s product code, which corresponds to the PRODUCT_CODE report dimension.
supports_reporting: Option<bool>Whether this ad client supports being reported on.