pub struct Alert {
pub id: Option<String>,
pub kind: Option<String>,
pub message: Option<String>,
pub severity: Option<String>,
pub type_: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>Unique identifier of this alert. This should be considered an opaque identifier; it is not safe to rely on it being in any particular format.
kind: Option<String>Kind of resource this is, in this case adexchangeseller#alert.
message: Option<String>The localized alert message.
severity: Option<String>Severity of this alert. Possible values: INFO, WARNING, SEVERE.
type_: Option<String>Type of this alert. Possible values: SELF_HOLD, MIGRATED_TO_BILLING3, ADDRESS_PIN_VERIFICATION, PHONE_PIN_VERIFICATION, CORPORATE_ENTITY, GRAYLISTED_PUBLISHER, API_HOLD.