pub struct CustomChannelTargetingInfo {
pub ads_appear_on: Option<String>,
pub description: Option<String>,
pub location: Option<String>,
pub site_language: Option<String>,
}Expand description
The targeting information of this custom channel, if activated.
This type is not used in any activity, and only used as part of another schema.
Fields
ads_appear_on: Option<String>The name used to describe this channel externally.
description: Option<String>The external description of the channel.
location: Option<String>The locations in which ads appear. (Only valid for content and mobile content ads). Acceptable values for content ads are: TOP_LEFT, TOP_CENTER, TOP_RIGHT, MIDDLE_LEFT, MIDDLE_CENTER, MIDDLE_RIGHT, BOTTOM_LEFT, BOTTOM_CENTER, BOTTOM_RIGHT, MULTIPLE_LOCATIONS. Acceptable values for mobile content ads are: TOP, MIDDLE, BOTTOM, MULTIPLE_LOCATIONS.
site_language: Option<String>The language of the sites ads will be displayed on.