pub struct PreferredDeals {
pub items: Option<Vec<PreferredDeal>>,
pub kind: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- preferreddeals list accounts (response)
Fields
items: Option<Vec<PreferredDeal>>The preferred deals returned in this list response.
kind: Option<String>Kind of list this is, in this case adexchangeseller#preferredDeals.