pub struct SavedReports {
pub etag: Option<String>,
pub items: Option<Vec<SavedReport>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- reports saved list accounts (response)
Fields
etag: Option<String>ETag of this response for caching purposes.
items: Option<Vec<SavedReport>>The saved reports returned in this list response.
kind: Option<String>Kind of list this is, in this case adexchangeseller#savedReports.
next_page_token: Option<String>Continuation token used to page through saved reports. To retrieve the next page of results, set the next request’s “pageToken” value to this.