pub struct UrlChannel {
pub id: Option<String>,
pub kind: Option<String>,
pub url_pattern: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>Unique identifier of this URL channel. This should be considered an opaque identifier; it is not safe to rely on it being in any particular format.
kind: Option<String>Kind of resource this is, in this case adexchangeseller#urlChannel.
url_pattern: Option<String>URL Pattern of this URL channel. Does not include “http://” or “https://”. Example: www.example.com/home