pub struct PreferredDeal {
pub advertiser_name: Option<String>,
pub buyer_network_name: Option<String>,
pub currency_code: Option<String>,
pub end_time: Option<u64>,
pub fixed_cpm: Option<i64>,
pub id: Option<i64>,
pub kind: Option<String>,
pub start_time: Option<u64>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- preferreddeals get accounts (response)
Fields
advertiser_name: Option<String>The name of the advertiser this deal is for.
buyer_network_name: Option<String>The name of the buyer network this deal is for.
currency_code: Option<String>The currency code that applies to the fixed_cpm value. If not set then assumed to be USD.
end_time: Option<u64>Time when this deal stops being active in seconds since the epoch (GMT). If not set then this deal is valid until manually disabled by the publisher.
fixed_cpm: Option<i64>The fixed price for this preferred deal. In cpm micros of currency according to currencyCode. If set, then this preferred deal is eligible for the fixed price tier of buying (highest priority, pay exactly the configured fixed price).
id: Option<i64>Unique identifier of this preferred deal.
kind: Option<String>Kind of resource this is, in this case adexchangeseller#preferredDeal.
start_time: Option<u64>Time when this deal becomes active in seconds since the epoch (GMT). If not set then this deal is active immediately upon creation.